# How to download and organize Swiss Ephemeris files

This guide explains how to properly organize your Swiss Ephemeris files to ensure they can be found and used correctly.

## Current Configuration

Your Swiss Ephemeris API is configured to look for ephemeris files at:
```
C:\Users\hunta\Documents\GitHub\swisseph\ephe
```

## Directory Structure

Swiss Ephemeris expects files to be organized as follows:

1. **Main directory** (e.g., `C:\Users\hunta\Documents\GitHub\swisseph\ephe`):
   - Planetary ephemeris files: `sepl_*.se1` (planets)
   - Moon ephemeris files: `semo_*.se1` (moon)
   - Main asteroid files: `seas_*.se1` (main asteroids)
   - JPL files (optional): `de*.eph` (e.g., `de431.eph`)

2. **Asteroid subdirectories**:
   - `ast0` - For asteroids with numbers 0-999
   - `ast1` - For asteroids with numbers 1000-1999
   - `ast2` - For asteroids with numbers 2000-2999
   - And so on...

## Your Current Setup

You currently have:
- ✅ All required planetary files in the correct location
- ✅ Moon ephemeris files in the correct location
- ✅ Main asteroid files in the correct location
- ✅ Saturn satellite files in the `sat` subdirectory
- ✅ I've created the `ast0`, `ast1`, and `ast2` directories for you
- ❌ No JPL files (these are optional but provide higher precision)

## How to Download Additional Files

### Asteroid Files

1. Visit the official download location:
   - [GitHub Repository](https://github.com/aloistr/swisseph/tree/master/ephe)
   - [Dropbox](https://www.dropbox.com/scl/fo/y3naz62gy6f6qfrhquu7u/h?rlkey=ejltdhb262zglm7eo6yfj2940&dl=0)

2. Download asteroid files and place them in the appropriate `astN` directories:
   - `se0*.se1` files go in `ast0` directory
   - `se1*.se1` files go in `ast1` directory
   - `se2*.se1` files go in `ast2` directory
   - And so on...

### JPL Files

For highest precision calculations, download one of these JPL files:

- [de200.eph](https://ssd.jpl.nasa.gov/ftp/eph/planets/Linux/de200/lnxm1600p2170.200) (41 MB)
- [de406.eph](https://ssd.jpl.nasa.gov/ftp/eph/planets/Linux/de406/lnxm3000p3000.406) (190 MB)
- [de431.eph](https://ssd.jpl.nasa.gov/ftp/eph/planets/Linux/de431/lnxm13000p17000.431) (2.6 GB)
- [de441.eph](https://ssd.jpl.nasa.gov/ftp/eph/planets/Linux/de441/linux_m13000p17000.441) (2.6 GB)

Place the downloaded file directly in your main ephemeris directory:
```
C:\Users\hunta\Documents\GitHub\swisseph\ephe
```

**Important:** After downloading, rename the file to match the expected name. For example, rename `linux_m13000p17000.441` to `de441.eph`.

## Testing Your Setup

Run the test script I've created to verify your configuration:

```bash
cd C:\Users\hunta\Documents\swiss-ephemeris-api
python test_ephemeris.py
```

This will check if all necessary files are in the correct locations and that Swiss Ephemeris can find them.

## API Configuration

Your Swiss Ephemeris API is already configured to use this path. If you want to change it:

1. Edit the `.env` file:
```
EPHE_PATH=C:\Users\hunta\Documents\GitHub\swisseph\ephe
```

2. For multiple search paths, use semicolons (;) as separators on Windows:
```
EPHE_PATH=C:\Path1;C:\Path2;C:\Path3
```

## Starting the API

After organizing your files, start the API with:

```bash
cd C:\Users\hunta\Documents\swiss-ephemeris-api
uvicorn app.main:app --reload
```
