@echo off
echo Starting Swiss Ephemeris API Setup...
echo.
cd /d "%~dp0"
echo Working directory: %CD%
echo.

REM Check if a virtual environment exists, if not create one
if not exist venv\ (
    echo Virtual environment not found. Creating one...
    python -m venv venv
    if errorlevel 1 (
        echo Failed to create virtual environment.
        echo Please make sure Python is installed and available in PATH.
        pause
        exit /b 1
    )
    echo Virtual environment created successfully.
)

REM Activate the virtual environment
echo Activating virtual environment...
call venv\Scripts\activate.bat
if errorlevel 1 (
    echo Failed to activate virtual environment.
    pause
    exit /b 1
)

REM Install required packages if not already installed
echo Checking for required packages...
pip show fastapi uvicorn pyswisseph python-dotenv pydantic > nul 2>&1
if errorlevel 1 (
    echo Installing required packages...
    pip install -r requirements.txt
    if errorlevel 1 (
        echo Failed to install required packages.
        pause
        exit /b 1
    )
    echo Packages installed successfully.
) else (
    echo Required packages already installed.
)

echo.
echo Starting Uvicorn server...
echo.
echo API will be available at: http://localhost:8000
echo Documentation available at: http://localhost:8000/docs
echo.
echo Press Ctrl+C to stop the server
echo.

REM Start the server
uvicorn app.main:app --reload --host 0.0.0.0 --port 8000

REM Keep window open in case of error
pause
